@@ -6,6 +6,6 @@ target_rpm_dir = '/tmp/o2_rpms'
 skip_deps = False
 force_build = False
 log_level='INFO'
-s3_bucket='s3://system-configuration/test/'
+s3_bucket='s3://system-configuration/RPMS/'
 release_tag='dev'
 architecture='slc7_x86-64'
